# Latest-Earthquake-News

This package will get the latest earthquake news from Indonesia BMKG Meteorological, Climatological And Geophysical
Agency

## About
This package will scrape from [BMKG](https://www.bmkg.go.id/?lang=EN)

This package uses beautifulsoup4 and requests to generate ready-to-use json output containing the latest earthquake info